@@ -1,6 +1,6 @@
 import string
-__version__ = string.split('$Revision: 1.7 $')[1]
-__date__ = string.join(string.split('$Date: 2001/08/10 18:42:33 $')[1:3], ' ')
+__version__ = string.split('$Revision: 1.8 $')[1]
+__date__ = string.join(string.split('$Date: 2001/11/17 14:12:34 $')[1:3], ' ')
 __author__ = 'Tarn Weisner Burton <twburton@users.sourceforge.net>'
 __doc__ = 'http://oss.sgi.com/projects/ogl-sample/registry/EXT/texture_env_combine.txt'
 __api_version__ = 0x107
@@ -33,7 +33,7 @@ GL_PREVIOUS_EXT = 0x8578
 
 def glInitTextureEnvCombineEXT():
 	from OpenGL.GL import __has_extension
-	return __has_extension("GL_EXT_texure_env_combine")
+	return __has_extension("GL_EXT_texture_env_combine")
 
 glInitTexEnvCombineEXT = glInitTextureEnvCombineEXT
 
