@@ -57,7 +57,11 @@ class build_py(distutils.command.build_py.build_py, distutils.command.config.con
 					if BUILD.has_key('libs'):
 						libs.extend(BUILD['libs'])
 					self.libraries = self.distribution.transform_libs(libs)
-					self.try_run(open(file).read())
+					self.try_run(
+						open(file).read(),
+						library_dirs = self.distribution.library_dirs,
+						include_dirs = self.distribution.include_dirs,
+					)
 					api_version_string = open('api_version').read()
 					if not api_version_string:
 						self.warn( """No current api_version_string, expect %s to be improperly generated"""%( file, ))
@@ -77,6 +81,7 @@ class build_py(distutils.command.build_py.build_py, distutils.command.config.con
 			except:
 				import traceback
 				traceback.print_exc()
+				self.warn( """Failure compiling version-selector, likely will be missing shadow modules for %r"""%( file,))
 			
 		distutils.command.build_py.build_py.run(self)
 
